@@ -1,9 +1,8 @@
 #  !/usr/bin/env python
-#   -*- coding: utf-8 -*-
 #
 #  doctools.py
 """
-Utilities for documenting functions, classes and methods
+Utilities for documenting functions, classes and methods.
 """
 #
 #  Copyright © 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
@@ -32,20 +31,33 @@ import builtins
 from textwrap import dedent
 from typing import Any, Callable, Optional, Sequence, Type, TypeVar, Union
 
+__all__ = [
+		"F",
+		"deindent_string",
+		"document_object_from_another",
+		"append_doctring_from_another",
+		"make_sphinx_links",
+		"is_documented_by",
+		"append_docstring_from",
+		"sphinxify_docstring",
+		]
+
 F = TypeVar('F', bound=Callable[..., Any])
 
 
-def deindent_string(string: str) -> str:
+def deindent_string(string: Optional[str]) -> str:
 	"""
-	Removes all indentation from the given string
+	Removes all indentation from the given string.
 
 	:param string: The string to deindent
-	:type string: str
 
 	:return: The string without indentation
-	:rtype: str
 	"""
 
+	if not string:
+		# Short circuit if empty string or None
+		return ''
+
 	split_string = string.split("\n")
 	deindented_string = [line.lstrip("\t ") for line in split_string]
 	return "\n".join(deindented_string)
@@ -96,19 +108,26 @@ def make_sphinx_links(input_string: str, builtins_list: Optional[Sequence[str]]
 	r"""
 	Make proper sphinx links out of double-backticked strings in docstring.
 
-	i.e. \`\`str\`\` becomes \:class\:\`~python:str\`
+	i.e.
 
+	.. code-block:: rest
 
-	Make sure to have `'python': ('https://docs.python.org/3/', None),` in the
-	`intersphinx_mapping` dict of your conf.py for sphinx.
+		``str``
 
-	:param input_string: The string to process
-	:type input_string: str
-	:param builtins_list: A list of builtins to make links for
-	:type builtins_list: list of str
+	becomes
+
+	.. code-block:: rest
+
+		:class:`~python:str`
+
+	Make sure to have ``'python': ('https://docs.python.org/3/', None),`` in the
+	``intersphinx_mapping`` dict of your ``conf.py`` file for Sphinx.
+
+	:param input_string: The string to process.
+	:param builtins_list: A list of builtins to make links for.
+	:default builtins_list: dir(:py:obj:`builtins`)
 
 	:return: processed string with links
-	:rtype: str
 	"""
 
 	if builtins_list is None:
@@ -159,10 +178,20 @@ def sphinxify_docstring() -> Callable:
 	r"""
 	Decorator to make proper sphinx links out of double-backticked strings in the docstring.
 
-	i.e. \`\`str\`\` becomes \:class\:\`~python:str\`
+	i.e.
 
-	Make sure to have `'python': ('https://docs.python.org/3/', None),` in the
-	`intersphinx_mapping` dict of your conf.py for sphinx.
+	.. code-block:: rest
+
+		``str``
+
+	becomes
+
+	.. code-block:: rest
+
+		:class:`~python:str`
+
+	Make sure to have ``'python': ('https://docs.python.org/3/', None),`` in the
+	``intersphinx_mapping`` dict of your ``conf.py`` file for Sphinx.
 	"""
 
 	def wrapper(target: F) -> F:
